Documentation
¶
Overview ¶
Package clock provides a clock app that provides customizable timers, alarms, stopwatches, and world clocks.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Timer ¶
type Timer struct {
core.Frame
// Duration is the total duration of the timer.
Duration time.Duration
// Start is when the timer was started.
Start time.Time
// Paused is whether the timer is currently paused.
Paused bool
// Name is the user-set name of the timer.
Name string
// contains filtered or unexported fields
}
Timer is a timer that can be paused, resumed, reset, and removed.
func NewTimer ¶
NewTimer returns a new Timer with the given optional parent: Timer is a timer that can be paused, resumed, reset, and removed.
func (*Timer) SetDuration ¶
SetDuration sets the Timer.Duration: Duration is the total duration of the timer.
Click to show internal directories.
Click to hide internal directories.